X-Git-Url: https://git.p6c8.net/jirafeau.git/blobdiff_plain/4c5e2caa3a0fedd86292b213c3bb3aa8c812d8c2..904c23884a5ad1b7cff5fa2a8dd962f699b9dd14:/lib/config.original.php
diff --git a/lib/config.original.php b/lib/config.original.php
index 76d5870..05631e6 100644
--- a/lib/config.original.php
+++ b/lib/config.original.php
@@ -15,7 +15,7 @@
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see .
+ * along with this program. If not, see .
*/
/*
@@ -24,29 +24,25 @@
*/
global $cfg;
-/* don't forget the ending '/' */
+/* Don't forget the ending '/' */
$cfg['web_root'] = '';
$cfg['var_root'] = '';
/* Lang choice between 'auto', 'en' and 'fr'.
- 'auto' mode will take the user's browser informations. Will take english if
- user's langage is not available.
+ * 'auto' mode will take the user's browser informations.
+ * Will take english if user's langage is not available.
*/
$cfg['lang'] = 'auto';
-$cfg['style'] = 'modern';
-$cfg['rewrite'] = false;
-/* preview: false (will download file) or true (will preview in browser if
- * possible) . */
+/* Select your style :) See media folder */
+$cfg['style'] = 'courgette';
+/* Propose a preview link if file type is previewable. */
$cfg['preview'] = true;
-/* Download page:
- * true: Will show a download page (with preview if permited and possible).
- * false: Will directly download file or preview (if permited and possible). */
-$cfg['download_page'] = false;
/* Encryption feature. disable it by default.
- * By enabling it, file-level deduplication won't work. */
+ * By enabling it, file-level deduplication won't work.
+ */
$cfg['enable_crypt'] = false;
-/* Split lenght of link refenrece. */
-$cfg['link_name_lenght'] = 8;
+/* Split length of link refenrece. */
+$cfg['link_name_length'] = 8;
/* Upload password(s). Empty array disable password authentification.
* $cfg['upload_password'] = array(); // No password
* $cfg['upload_password'] = array('psw1'); // One password
@@ -54,6 +50,13 @@ $cfg['link_name_lenght'] = 8;
* ... and so on
*/
$cfg['upload_password'] = array();
+/* List of IP allowed to upload a file.
+ * If list is empty, then there is no upload restriction based on IP
+ * Elements of the list can be a single IP (e.g. "123.45.67.89") or
+ * an IP range (e.g. "123.45.0.0/16").
+ * Note that CIDR notation is available for IPv4 only for the moment.
+ */
+$cfg['upload_ip'] = array();
/* An empty admin password will disable the classic admin password
* authentication.
*/
@@ -65,6 +68,34 @@ $cfg['admin_password'] = '';
* If admin_password parameter is also set, admin_password is ignored.
*/
$cfg['admin_http_auth_user'] = '';
+/* Select different options for availability of uploaded files.
+ * Possible values in array:
+ * 'minute': file is available for one minute
+ * 'hour': file available for one hour
+ * 'day': file available for one day
+ * 'week': file available for one week
+ * 'month': file is available for one month
+ * 'year': file available for one year
+ * 'none': unlimited availability
+ */
+$cfg['availabilities'] = array ('minute' => true,
+ 'hour' => true,
+ 'day' => true,
+ 'week' => true,
+ 'month' => true,
+ 'year' => false,
+ 'none' => false);
+/* Set maximal upload size expressed in MB.
+ * 0 mean unlimited upload size.
+ */
+$cfg['maximal_upload_size'] = 0;
+/* If your Jirafeau is behind some reverse proxies, you can set there IPs
+ * so Jirafeau get visitor's IP from HTTP_X_FORWARDED_FOR instead of
+ * REMOTE_ADDR.
+ * for example:
+ * $cfg['proxy_ip'] = array('12.34.56.78');
+ */
+$cfg['proxy_ip'] = array();
/* Installation is done ? */
$cfg['installation_done'] = false;